import { IPageData, HtLocation, GeoJson, IPlace } from "./common";
import { IUser } from "./user";
import { ITimeAwarePoint } from "./common";
import { IPlaceline } from "./placeline";
export interface IAction {
    id: string;
    user: {
        created_at: string;
        group_id: string | null;
        id: string;
        is_tracking: boolean;
        name: string | null;
        phone: string | null;
        photo: string | null;
        unique_id: string | null;
        display: {
            last_updated_text: string;
            status_text: string;
            is_warning: boolean;
            warning_since_text: string;
        };
        vehicle_type: string;
    };
    display: {
        status_text: string;
        sub_status_text: string;
        duration_remaining: number;
        is_late: boolean;
        duration_elapsed: number;
        distance_remaining: string | null;
    };
    unique_id: string;
    arrival_status: string;
    distance_to_arrival: null | number;
    distance: number | null;
    duration: number | null;
    created_at: string;
    started_at: string;
    started_place: IPlace;
    completed_place: IPlace;
    completed_at: string | null;
    activity: null | {
        type: string;
        distance: number;
        duration: number;
        steps: number;
        started_at: string;
    };
    health: null | {
        battery_percentage: number;
        network_status: string;
        location_status: string;
        battery_status: string;
    };
    location: null | HtLocation;
    place?: IPlace;
    expected_place: IPlace;
    eta_at_creation: string;
    eta: string;
    status: string;
    expected_at: string | null;
    type: string;
    tracking_url: string;
    route: string;
    expected_route: string;
    location_time_series: string;
    event_flags: string[];
    metadata: object;
}
export interface IActionMap {
    id: string;
    lookup_id: string;
    type: string;
    status: string;
    created_at: string;
    expected_place: {
        location: GeoJson;
    } | null;
    expected_at: string | null;
    eta: string | null;
    initial_eta: string | null;
    completed_at: string | null;
    completed_place: {
        location: GeoJson;
    } | null;
    display: {
        status_text: string;
        sub_status_text: string;
        duration_remaining: number;
        show_summary: boolean;
        is_late: boolean;
    };
    user: {
        id: string;
        name: string;
    };
}
export interface IActionHeat {
    completed_place_id: string;
    completed_place__location: [number, number];
    num_actions: number;
}
export interface IActionHeatPage extends IPageData {
    results: IActionHeat[];
}
export interface IActionPage extends IPageData {
    results: IAction[];
}
export interface IActionMapPage extends IPageData {
    results: IActionMap[];
}
export interface IActionStatusGraph extends IActionsSummary {
    created_date: string;
}
export interface IActionsSummary {
    created: number;
    completed: number;
    autocompleted: number;
    canceled: number;
    autocanceled: number;
}
export interface ITrackAction {
    user: IUser;
    actions: IAction[];
    account: {
        logo: string | null;
    };
}
export interface IActionWithPolyline extends IAction {
    timeAwarePath?: ITimeAwarePoint[];
}
export interface IActionMod extends IActionWithPolyline {
    timeAwarePath: ITimeAwarePoint[];
}
export interface IActionPlaceline extends IAction {
    placeline: IPlaceline[];
}
